#include <gda-ui.h>

/* Define constants that relate to the position
   of the label and id column in the initial query
*/
#define LABEL_COLUMN 0
#define ID_COLUMN 1

gchar* get_selected_label(GtkWidget* combo);
gchar* get_selected_id(GtkWidget* combo);
GtkWidget* create_gda_combo(Gda_Connection* cnc,
                            gchar* table, 
                            gchar* label_col, 
                            gchar* id_col);

